@@ -17,7 +17,6 @@ has file => ( default => sub { PNI::File->new } );
 
 sub add_edge {
     my $self = shift;
-
     my $edge = PNI::Edge->new(@_);
     return $self->edges->add($edge);
 }
@@ -32,15 +31,14 @@ sub add_node {
 
         my $node_class = "PNI::Node::$type";
 
+        # Code to require a node, before using UNIVERSAL::required looked like this.
+        #        my $node_path  = "$node_class.pm";
+        #        $node_path =~ s/::/\//g;
+        #        eval { require $node_path };
+
         $node_class->require or return;
 
-     # TODO: Set input data, if any
-     #while ( my ( $slot_name, $slot_data ) = each %{ $arg->{inputs} or {} } ) {
-     #    $node->get_input($slot_name)->set_data($slot_data);
-     #}
-
-        $node = $node_class->new( father => $self, type => $type, @_ );
-
+        $node = $node_class->new( father => $self );
     }
     else {
 
@@ -49,41 +47,42 @@ sub add_node {
 
     }
 
+    # TODO: Set input data, if any
+    #while ( my ( $slot_name, $slot_data ) = each %{ $arg->{inputs} or {} } ) {
+    #    $node->get_input($slot_name)->set_data($slot_data);
+    #}
+
     return $self->nodes->add($node);
 }
 
 sub add_scenario {
-    my $self = shift;
-
+    my $self     = shift;
     my $scenario = PNI::Scenario->new(@_);
     return $self->scenarios->add($scenario);
 }
 
 sub del_edge {
     my $self = shift;
-
     my $edge = shift or return;
 
     $edge->source->edges->del($edge);
     $edge->target->edge(undef);
 
-    return $self->edges->del($edge);
+    $self->edges->del($edge);
 }
 
 sub del_node {
     my $self = shift;
-
     my $node = shift or return;
 
     $self->del_edge($_) for $node->get_ins_edges;
     $self->del_edge($_) for $node->get_outs_edges;
 
-    return $self->nodes->del($node);
+    $self->nodes->del($node);
 }
 
 sub del_scenario {
     my $self = shift;
-
     my $scenario = shift or return;
 
     # Clean up all items contained in the scenario.
@@ -93,7 +92,7 @@ sub del_scenario {
 
     $scenario->del_scenario($_) for $scenario->scenarios->list;
 
-    return $self->scenarios->del($scenario);
+    $self->scenarios->del($scenario);
 }
 
 sub task {
@@ -157,31 +156,10 @@ sub task {
     # Finally, run all sub scenarios tasks.
     $_->task for ( $self->scenarios->list );
 
-    # TODO dovrei mettere un return piu significativo tipo return $self->ok
     return 1;
 }
 
-# TODO this method is EXPERIMENTAL, needs tests and code cleaning.
-sub to_hash {
-    my $self = shift;
-
-    my $nodes_list = [];
-    for my $node ( $self->nodes->list ) {
-        push @{$nodes_list}, $node->to_hash;
-    }
-
-    # TODO prima dovrei prendere il SUPER to_hash
-    # ad esempio PNI::Elem to_hash mi da l' id.
-    return {
-        id        => $self->id,
-        nodes     => $nodes_list,
-        edges     => 0,
-        scenarios => 0,
-    };
-}
-
-1;
-
+1
 __END__
 
 =head1 NAME
@@ -195,48 +173,34 @@ PNI::Scenario - is a set of nodes connected by edges
     $standalone_scenario = PNI::Scenario->new;
 
     # ... but it will not belong to PNI hierarchy tree,
-    # so its task method will not be called, unless you call it.
-    $standalone_scenario->task;
+    # so its task method will not be called.
 
     # You can start adding a scenario to the PNI root.
     use PNI;
-    my $scenario = PNI::root->add_scenario;
+    my $scen1 = PNI::root->add_scenario;
+    my $scen2 = $scenario->add_scenario;
 
-    # Add two nodes.
-    my $foo = $scenario->add_node('Foo');
-    my $bar = $scenario->add_node('Bar');
-
-    # Connect nodes with an edge.
-    $scenario->add_edge( $foo => $bar, 'out' => 'in' );
-
-    # Calling PNI task method will execute all the tasks once.
-    PNI::task;
-
-    # Or call PNI loop to keep it running.
-    PNI::loop;
-
-
-=head1 DESCRIPTION
-
-A scenario is a directed graph of subs called C<task>.
+    my $foo = $scen2->add_node('Foo');
+    my $bar = $scen2->add_node('Bar');
+    $scen2->add_edge( $foo => $bar, 'out' => 'in' );
 
 =head1 ATTRIBUTES
 
 =head2 edges
 
-    my @edges = $scenario->edges->list;
+    my @edges = $self->edges->list;
 
 A L<PNI::Set> containing <PNI::Edge>s.
 
 =head2 nodes
 
-    my @nodes = $scenario->nodes->list;
+    my @nodes = $self->nodes->list;
 
 A L<PNI::Set> containing <PNI::Node>s.
 
 =head2 scenarios
 
-    my @scenarios = $scenario->scenarios->list;
+    my @scenarios = $self->scenarios->list;
 
 A L<PNI::Set> containing <PNI::Scenario>s.
 
@@ -248,8 +212,6 @@ A L<PNI::Set> containing <PNI::Scenario>s.
 
 =head2 add_scenario
 
-    $sub_scenario = $scenario->add_scenario;
-
 =head2 del_edge
 
 =head2 del_node
@@ -258,14 +220,5 @@ A L<PNI::Set> containing <PNI::Scenario>s.
 
 =head2 task
 
-    $scen->task;
-
-Probably the most important PNI method. The task of a scenario is to trigger 
-every node (and scenario) it contains to run its own task, following the natural order.
-
-=head2 to_hash
-
-    my $data_hashref = $scen->to_hash;
-
 =cut
 
